@@ -103,7 +103,7 @@
 #define MAX_NUMBER_OF_REDIRECTIONS   4
 
 #define NOTIFICATIONS_MARGIN       16
-#define NOTIFICATIONS_WIDTH        300
+#define NOTIFICATIONS_WIDTH        350
 #define NOTIFICATIONS_TIMEOUT      10s
 #define NOTIFICATION_SHORT_TIMEOUT 3s
 #define NOTIFICATIONS_PAGE_SIZE    10
@@ -227,17 +227,21 @@
 
 #define APP_SKIN_USER_FOLDER   "skins"
 #define APP_SKIN_DEFAULT       "minimal-light"
+#define APP_SKIN_DEFAULT_DARK  "minimal-dark"
 #define APP_SKIN_METADATA_FILE "metadata.xml"
 
 #if defined(FORCE_BUNDLE_ICONS)
 // Forcibly bundle icons.
-#define APP_ICON_THEME_DEFAULT "Breeze"
+#define APP_ICON_THEME_DEFAULT      "Breeze"
+#define APP_ICON_THEME_DARK_DEFAULT "Breeze Dark"
 #elif defined(Q_OS_UNIX) && !defined(Q_OS_MACOS)
 // Do not force default icon theme on Linux.
-#define APP_ICON_THEME_DEFAULT ""
+#define APP_ICON_THEME_DEFAULT      ""
+#define APP_ICON_THEME_DARK_DEFAULT ""
 #else
 // Use some default theme otherwise.
-#define APP_ICON_THEME_DEFAULT "Breeze"
+#define APP_ICON_THEME_DEFAULT      "Breeze"
+#define APP_ICON_THEME_DARK_DEFAULT "Breeze Dark"
 #endif
 
 #define APP_LOCAL_ICON_THEME_FOLDER "icons"
